@@ -1,5 +1,14 @@
 from datetime import datetime, timedelta, timezone
 
+def count(seq, cond=None):
+    """Count the number of items from a sequence matching condition `cond`
+    """
+    if cond is None:
+        cond = lambda x: True
+
+    return sum(1 for x in seq if cond(x))
+
+
 def single(seq, cond=None):
     """Extract a single item from a sequence matching condition `cond`
 
